@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use strict;
 use warnings;
@@ -71,6 +71,22 @@ sub	config2perl {
 		($tvop, $tvcl) = @{ $params->{'tags'} };
 	} else { $tvop = '<%'; $tvcl = '%>' }
 
+	# check that the tags for verbatim sections is not the same as comments
+	while( $commentstyle =~ /\bcustom\((.+?)\)\((.*?)\)/ig ){
+		my $coop = $1; my $cocl = $2;
+		if( $debug > 0 ){ warn __PACKAGE__.'::configfile2perl()'." (line ".__LINE__.") : checking comment tags '${coop}' and '${cocl}' not to be the same or contain verbatim/variables tags '${tvop}' and '${tvcl}' ..." }
+		if( ($tvop eq $coop) || ($tvop eq $cocl)
+		 || ($tvcl eq $coop) || ($tvcl eq $cocl)
+		){ warn __PACKAGE__.'::configfile2perl()'." (line ".__LINE__.") : error, there is a clash (exact match) with verbatim/variable tags ('${tvop}' and '${tvcl}') and comment tags ('${coop}' and '${cocl}')."; return undef }
+		# also check if one contains the other
+		if( ($tvop =~ /\Q${coop}\E/) || ($tvop =~ /\Q${cocl}\E/)
+		 || ($tvcl =~ /\Q${coop}\E/) || ($tvcl =~ /\Q${cocl}\E/)
+		){ warn __PACKAGE__.'::configfile2perl()'." (line ".__LINE__.") : error, there is a clash (one contains the other) with verbatim/variable tags ('${tvop}' and '${tvcl}') and comment tags ('${coop}' and '${cocl}')."; return undef }
+		if( ($coop =~ /\Q${tvop}\E/) || ($coop =~ /\Q${tvcl}\E/)
+		 || ($cocl =~ /\Q${tvop}\E/) || ($cocl =~ /\Q${tvcl}\E/)
+		){ warn __PACKAGE__.'::configfile2perl()'." (line ".__LINE__.") : error, there is a clash (one contains the other) with verbatim/variable tags ('${tvop}' and '${tvcl}') and comment tags ('${coop}' and '${cocl}')."; return undef }
+	}
+
 	my $tsubs = exists($params->{'variable-substitutions'})
 		? $params->{'variable-substitutions'} : undef
 	;
@@ -95,7 +111,14 @@ sub	config2perl {
 	}
 	# this is a warning:
 	# we can not be sure if this <% xyz %> is part of the content or a forgotten templated variable
-	if( $contents =~ /\Q${tvop}\E\s*!(:?(:?begin-verbatim-section)|(:?end-verbatim-section))\s*\Q${tvcl}\E/ ){ warn "--begin content:\n".$contents."\n--end content.\n".__PACKAGE__.'::config2perl()'." (line ".__LINE__.") : warning, there may still be remains of templated variables in the specified content, see above what remained after all template variables substitutions were done." }
+	# NOTE: During test t/090-config2perl-failed-verbatim.t some CPAN testers
+	# report a failure. The fact is that this test deliberately tests a failed case
+	# and the line below should cause the sub to exit and print a long winded, multiline error message.
+	# So, some testers (3/15) report a failure.
+	# see https://www.cpantesters.org/cpan/report/fbbe94b6-62e8-11ee-9f69-c1f66d8775ea
+	# So, I am replacing the comment with a short comment.
+	#if( $contents =~ /\Q${tvop}\E\s*!(:?(:?begin-verbatim-section)|(:?end-verbatim-section))\s*\Q${tvcl}\E/ ){ print STDERR "--begin content:\n".$contents."\n--end content.\n".__PACKAGE__.'::config2perl()'." (line ".__LINE__.") : warning, there may still be remains of templated variables in the specified content (tags used: '${tvop}' and '${tvcl} -- ignore the enclosing single quotes), see above what remained after all template variables substitutions were done." }
+	if( $contents =~ /\Q${tvop}\E\s*!(:?(:?begin-verbatim-section)|(:?end-verbatim-section))\s*\Q${tvcl}\E/ ){ print STDERR __PACKAGE__.'::config2perl()'." (line ".__LINE__.") : warning, there may still be remains of templated variables in the specified content (tags used: '${tvop}' and '${tvcl}' -- ignore the enclosing single quotes), see above what remained after all template variables substitutions were done." }
 
 	# secondly, remove the VERBATIM multiline sections and transform them.
 	# Comments inside the verbatim section will NOT BE touched.
@@ -201,7 +224,7 @@ Config::JSON::Enhanced - JSON-based config with C/Shell-style comments, verbatim
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
@@ -437,6 +460,9 @@ has the custom tags escaped for special regex characters
 (with the C<\Q ... \E> construct). So you are pretty safe in using
 any character. Please report weird behaviour.
 
+B<Warning> : either opening or closing comment tags must not
+be the same as opening or closing variables / verbatim section tags.
+
 =back
 
 =item * C<variable-substitutions> : a hashref whose keys are
@@ -552,6 +578,9 @@ comment will be removed.
 =item * Unfortunately, there is not support for ignoring B<superfluous commas> in JSON,
 in the manner of glorious Perl.
 
+B<Warning> : either opening or closing comment tags must not
+be the same as opening or closing variables / verbatim section tags.
+
 =back
 
 =head2 Verbatim Sections
